<?php
/*
 * This file is part of Web Pro Manager.
 * 
 * Web Pro Manager is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Web Pro Manager is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Web Pro Manager.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * @author The Web Pro Miami, Inc. <info@thewebpro.com>
 * @copyright The Web Pro Miami, Inc. <info@thewebpro.com>, http://www.thewebpro.com/
 * @license http://www.gnu.org/licenses/gpl.html GNU GPL
 * @package WebProManager
*/

// ver 1.1.7
// 1.0.2 - added validation min/max length
// 1.0.3 - added static field type (non-editable, non-submittable item)
// 1.0.4 - completed email integration, fixed cancel redirect button bug
// 1.0.5 - fixed "checkbox" select bug
// 1.0.6 - added onBlur event for all fields
// 1.0.7 - added SQLNoQuotes to allow certain items to have no quotes in SQL string (i.e. integers)
// 1.0.8 - added class/style to form groups, added basic support for File input type with NO processing (must be included in DontProcess and processed separately)
// 1.0.9 - added "processed" notification to forms that do not use additional post-processing (db or email), added IDs to save/cancel buttons
// 1.1.0 - added "ClearAfter" to Group class, moved group div style up one level (to now include header) allowing for floating divs
// 1.1.0b - updated "onChange" to "onClick" for onBlue event linkup with checkboxes, added "editBoxInner" ID to hook style for grouped inner form elements as a whole, added "nClearFinal" at end of form
// 1.1.1 - added Caption to Form Group, updated "required" fields to show asterisk on caption if available and title is not
// 1.1.2 - added ItemStyle to Form Field, removed unneeded "<br>" from behind Checkbox field item
// 1.1.3 - added ID tag to SELECT field (was just NAME tag)
// 1.1.4 - added BeforeField and AfterField to place text before/after fields
// 1.1.5 - added ID tag to Form Group (for external calls like Tab Grouping)
// 1.1.6 - updated onBlur event on file upload field to onClick, updated code to use nCloseScript var
// 1.1.7 - added rich-text editor (FCKeditor) as new field type "rte", added OnSubmitScriptARRAY for script validation/usage before submitting form
class Form {
	var $HasProcessed, $Action, $Encoding, $Method, $Name, $ClearAfter, $SubmitText, $CancelText, $CancelRedirect, $Redirect, $DontProcess, $SQLNoQuotes, $DEBUG;
	var $DBName,$DBLink,$AddToDBTable,$ModifyDBTable,$ModifyDBID,$ModifyDBField,$nUseADODB,$SubmitToJS;
	var $EncodeRC4ARRAY = array(), $GroupARRAY = array(), $ValReqARRAY = array(), $ValEmailARRAY = array(), $ValNumARRAY = array(), $ValPhoneARRAY = array(), $ValDateARRAY = array(), $ValCCARRAY = array(), $OnSubmitScriptARRAY = array();
	var $ValMaxLengthARRAY = array(), $ValMaxLengthParamARRAY = array(), $ValMinLengthARRAY = array(), $ValMinLengthParamARRAY = array();
	var $Action_email, $Action_email_bodyFile, $MailHost, $MailUser, $MailPass, $MailFrom, $EmailFromName, $EmailSubject;
	
	function Form(){
		// set defaults
		$this->Method = "post";
		$this->SubmitText = "Submit";
		$this->CancelText = "Cancel";
		$this->HasProcessed = 0;
	}
	function AddGroup($nGroupObj){
		$this->GroupARRAY[] = $nGroupObj;
	}
	function AddValidation($nValType,$nFieldObj,$nValParam=""){
		$nFieldObj->AddValidation($nValType,$nValParam);
		switch($nValType){
			case "required": $this->ValReqARRAY[] = $nFieldObj->ID; break;
			case "email": $this->ValEmailARRAY[] = $nFieldObj->ID; break;
			case "numeric": $this->ValNumARRAY[] = $nFieldObj->ID; break;
			case "phone": $this->ValPhoneARRAY[] = $nFieldObj->ID; break;
			case "date": $this->ValDateARRAY[] = $nFieldObj->ID; break;
			case "cc": $this->ValCCARRAY[] = $nFieldObj->ID; break;
			case "maxlength": if($nValParam){ $this->ValMaxLengthARRAY[] = $nFieldObj->ID; $this->ValMaxLengthParamARRAY[$nFieldObj->ID] = $nValParam; } break;
			case "minlength": if($nValParam){ $this->ValMinLengthARRAY[] = $nFieldObj->ID; $this->ValMinLengthParamARRAY[$nFieldObj->ID] = $nValParam; } break;
		}
		return $nFieldObj;
	}
	function AddOnSubmitScript($nOnSubmitScript,$nFieldObj){
		$this->OnSubmitScriptARRAY[] = $nOnSubmitScript;
		return $nFieldObj;
	}
	function AddEncoding($nEncType,$nFieldObj){
		// encoding (done before final processing)
		switch($nEncType){
			case "RC4": $this->EncodeRC4ARRAY[] = $nFieldObj->ID; break;
		}
		return $nFieldObj;
	}
	function GetForm(){
		// prepare scripts, if needed
		$nOnSubmitScriptCode = "";
		foreach($this->OnSubmitScriptARRAY AS $nOnSubmitScript){ $nOnSubmitScriptCode.= $nOnSubmitScript; }
		if($nOnSubmitScriptCode){
			if($this->SubmitToJS){ $this->SubmitToJS = "if(formOnSubmitScript()){ ".$this->SubmitToJS." }"; }
			$nOnSubmitScriptCode = "<script>formOnSubmitScript = function(){ $nOnSubmitScriptCode return true; }</script>";
		}
		// returns full form, with all groups and fields
		if($this->Encoding){ $nEncoding = "enctype=\"$this->Encoding\""; }
		if($this->SubmitToJS){
			$Opener = "<form action=\"$this->Action\" method=\"$this->Method\" name=\"$this->Name\" id=\"$this->Name\" style=\"margin:0px;\" onSubmit=\"$this->SubmitToJS\" $nEncoding>";
		} else {
			$Opener = "<form action=\"$this->Action\" method=\"$this->Method\" name=\"$this->Name\" id=\"$this->Name\" style=\"margin:0px;\" $nEncoding>";
		}
		$Opener.="<input type=\"hidden\" name=\"nProcess\" id=\"nProcess\" value=\"1\">";
		$CloserButtons = "<input type=\"submit\" name=\"nSave\" id=\"nSave\" value=\"$this->SubmitText\" class=\"formSubmit\"> ";
		if(!$this->CancelRedirectIsJS && $this->CancelRedirect){ $this->CancelRedirect = "document.location.href='$this->CancelRedirect'"; }
		if($this->CancelRedirect){ $CloserButtons.= "<input type=\"button\" name=\"nCancel\" id=\"nCancel\" value=\"$this->CancelText\" class=\"formCancel\" onClick=\"$this->CancelRedirect\">"; }
		$Closer.= "</form>";
		$nFormGroupCode = "";
		foreach ($this->GroupARRAY AS $nGroup){
			if(is_object($nGroup)){
				$nFormGroupCode.= $nGroup->GetFormGroup();
			}
		}
		// if form has been posted, process it
		if($_POST["nProcess"]){
			$nDEBUG = $this->DEBUG; // turns off/on general debugging, including PHPMailer comprehensive debugging
			// Where the form goes after successful submission
			$nRedirect = $this->Redirect;
			// Required fields (multiple values accepted, comma-delimited)
			$nRequired = implode(",",$this->ValReqARRAY);
			// Fields to be validated (multiple values accepted, comma-delimited)
			$nValidate_email = implode(",",$this->ValEmailARRAY);
			$nValidate_numeric = implode(",",$this->ValNumARRAY);
			$nValidate_phone = implode(",",$this->ValPhoneARRAY);
			$nValidate_date = implode(",",$this->ValDateARRAY);
			$nValidate_cc = implode(",",$this->ValCCARRAY);
			$nValidate_maxlength = implode(",",$this->ValMaxLengthARRAY); $nValParam_maxlengthARRAY = $this->ValMaxLengthParamARRAY;
			$nValidate_minlength = implode(",",$this->ValMinLengthARRAY); $nValParam_minlengthARRAY = $this->ValMinLengthParamARRAY;
			// Fields to be encoded (multiple values accepted, comma-delimited)
			$nEncode_RC4 = implode(",",$this->EncodeRC4ARRAY);
			// Dont process these fields (multiple values accepted, comma-delimited)
			$nDontProcessARRAY[] = "nSave,nCancel,_";
			$nDontProcessARRAY[] = $this->DontProcess;
			$nDontProcess = implode(",",$nDontProcessARRAY);
			// Dont allow quotes around these items in the database SQL string
			$nSQLNoQuotes = $this->SQLNoQuotes;
			// Mail settings (leave everything blank if you don't want to send mail)
			$nAction_email = $this->Action_email; // (multiple values accepted, comma-delimited)
			$nAction_email_bodyFile = $this->Action_email_bodyFile;
			$nMailHost = $this->MailHost;
			$nMailUser = $this->MailUser;
			$nMailPass = $this->MailPass;
			$nMailFrom = $this->MailFrom;
			$nEmailFromName = $this->EmailFromName;
			$nEmailSubject = $this->EmailSubject;
			// Database settings (leave each blank if not in use)
			$DBName = $this->DBName; $Link = $this->DBLink;
			$nAction_addtodb = $this->AddToDBTable;  // Adds data submitted to this table
			$nAction_modifydb = $this->ModifyDBTable; // Updates this table with data submitted (nAction_modifydb_id required)
			$nAction_modifydb_id = $this->ModifyDBID; // Set this to update an item (PHP can be used here)
			$nAction_modifydb_field = $this->ModifyDBField; // Set this to the field of the item to update (PHP can be used here)
			$nAction_use_adodb = $this->nUseADODB;
			// Translate these fields within a database (multiple values accepted, comma-delimited)
			// (field to be translated_db table name_db field name,...)
			$nTranslate ="";
			// Process...
			include_once("form_process.php");
			if($nFormProcessed){ $this->HasProcessed = 1; }
			if(!$nError && !$nAction_email && !$nAction_addtodb && !$nAction_modifydb){ $this->HasProcessed = 1; }
		}
		if($nError){ $nErrorCode = "<div id=\"errorBox\">$nError</div>"; }
		// if form processes requests this class to do the redirecting...
		if($nProcessRedirect){ return $nProcessRedirect; }
		if($CloserButtons){ $CloserButtons="<div align=\"center\" id=\"buttonBox\">$CloserButtons</div>"; }
		$nClearFinal = "<div style=\"clear:both;\">&nbsp;</div>";
		return $nOnSubmitScriptCode.$nErrorCode.$Opener.$nFormGroupCode.$nClearFinal.$CloserButtons.$Closer;
	}
}

class FormGroup {
	var $Name, $Style, $Class, $Caption, $ID;
	var $FieldARRAY = array();
	
	function FormGroup (){
		// set defaults
	}
	function AddField($nFieldObj){
		$this->FieldARRAY[] = $nFieldObj;
	}
	function GetFormGroup(){
		$nGroupName = $this->Name;
		$nCaption = $this->Caption;
		$nFormFieldCode = "";
		foreach ($this->FieldARRAY AS $nField){
			if(is_object($nField)){
				$nFormFieldCode.= $nField->GetFormField();
			}
		}
		if($nGroupName){ $nGroupName = "<div id=\"editBoxHdr\"><span id=\"fieldGrpTitle\">$nGroupName</span><BR>$nCaption</div>"; }
		if($this->ClearAfter){ $nClearAfter = "<div style=\"clear:both;\">&nbsp;</div>"; } else { $nClearAfter = ""; }
		return <<<CODE
	<div id="$this->ID" style="$this->Style" class="$this->Class">
		$nGroupName
		<div id="editBoxInner">
			$nFormFieldCode
		</div>
	</div>
	$nClearAfter
CODE;
	}
}

class FormField {
	var $Type, $ID, $Label, $Caption, $Value, $Style, $Class, $RowSize, $RowStyle, $ItemStyle, $onBlur, $BeforeField, $AfterField;
	var $DataARRAY = array(),$SelectedARRAY = array(),$ValidationARRAY = array(),$ValParamARRAY = array();
	
	function FormField ($nType="text",$nID="",$nLabel=""){
		// set defaults
		$this->Type = trim($nType);
		$this->ID = trim($nID);
		$this->Label = trim($nLabel);
		$this->RowSize = "Full";
	}
	function AddValidation($nValType,$nValParam=""){
		$this->ValidationARRAY[] = $nValType;
		$this->ValParamARRAY[$nValType] = $nValParam;
	}
	function GetFormField(){
		// validation
		$nReqCode = "";
		foreach($this->ValidationARRAY AS $nValType){
			switch($nValType){
				case "required":	$nRequired = 1; $nReqCode = "<span class=\"r\">*</span>"; break;
				case "email":		$nValidateEmail = 1; break;
				case "numeric":		$nValidateNum = 1; break;
				case "phone":		$nValidatePhone = 1; break;
				case "date":		$nValidateDate = 1; break;
				case "cc":			$nValidateCC = 1; break;
				case "maxlength":	$nValidateMaxlength = 1; $nValMaxLengthParam = $this->ValParamARRAY[$nValType]; break;
				case "minlength":	$nValidateMinlength = 1; $nValMinLengthParam = $this->ValParamARRAY[$nValType];break;
			}
		}
		if($this->Label){ $this->Label = $this->Label."$nReqCode"; }
		if(!$this->Label && $this->Caption){ $this->Caption = $this->Caption."$nReqCode"; }
		if($this->Label){ $nLabel = "<div id=\"fieldTitle\">$this->Label</div>"; }
		if($this->Caption){ $nCaption = "<label for=\"$this->ID\" class=\"caption\">$this->Caption</label>"; }
		if($this->RowSize=="Full"){ $nRowDivID = "fieldRowFull"; } else { $nRowDivID = "fieldRowDualCols"; }
		// if form has been posted, use posted values
		if($_POST["nProcess"]){
			if($this->Type!="static"){ $this->Value = trim($_POST[$this->ID]); }
			// required fields
			switch($this->Type){
				case "checkbox":
					$nSelectedAmt = 0;
					foreach($this->DataARRAY AS $Key => $Item){ if($_POST[$Key]==$Key){ $nSelectedAmt++; } }
					if($nRequired && !$nSelectedAmt){ $this->Style = "border:1px solid #FF0000;".$this->Style; $nAddTrigger=1; }
					break;
				default: if($nRequired && !$this->Value){ $this->Style = "border:1px solid #FF0000;".$this->Style; }
			}
			// other validation
			if($this->Value){
				if($nValidateEmail && !validate_email($this->Value)){ $this->Style = "border:1px solid #FF0000;".$this->Style; }
				if($nValidateNum && !validate_num($this->Value)){ $this->Style = "border:1px solid #FF0000;".$this->Style; }
				if($nValidatePhone && !validate_phone($this->Value)){ $this->Style = "border:1px solid #FF0000;".$this->Style; }
				if($nValidateDate && !validate_date($this->Value)){ $this->Style = "border:1px solid #FF0000;".$this->Style; }
				if($nValidateCC && !validate_cc($this->Value)){ $this->Style = "border:1px solid #FF0000;".$this->Style; }
				if($nValidateMaxlength && !validate_maxlength($this->Value,$nValMaxLengthParam)){ $this->Style = "border:1px solid #FF0000;".$this->Style; }
				if($nValidateMinlength && !validate_minlength($this->Value,$nValMinLengthParam)){ $this->Style = "border:1px solid #FF0000;".$this->Style; }
			}
		}
		// JS Events
		$nCloseScript = "</script>";
		if($this->onBlur){ $this->onBlur = "onBlur=\"$this->onBlur\""; }
		switch($this->Type){
			case "text":
				$nFormFieldCode = <<<CODE
	<div id="fieldGrpBox" style="$this->RowStyle">$nLabel
		<div id="$nRowDivID" style="clear:both;">
			<div id="fieldItem" style="$this->ItemStyle">$this->BeforeField<input type="text" name="$this->ID" id="$this->ID" value="$this->Value" style="$this->Style" $this->onBlur>$this->AfterField$nCaption</div>
		</div>
	</div>
CODE;
				break;
			case "date":
				$nFormFieldCode = <<<CODE
	<div id="fieldGrpBox" style="$this->RowStyle">$nLabel
		<div id="$nRowDivID" style="clear:both;">
			<div id="fieldItem" style="$this->ItemStyle">$this->BeforeField<input type="text" name="$this->ID" id="$this->ID" value="$this->Value" style="$this->Style" size="10" maxlength="10" class="format-m-d-y divider-slash highlight-days-12 no-transparency" $this->onBlur>$this->AfterField$nCaption</div>
		</div>
	</div>
	<script>
	datePickerController.create(document.getElementById("$this->ID"));
	$nCloseScript
CODE;
				break;
			case "hidden":
				$nFormFieldCode = "<input type=\"hidden\" name=\"$this->ID\" id=\"$this->ID\" value=\"$this->Value\" style=\"$this->Style\">";
				break;
			case "textarea":
				$nFormFieldCode = <<<CODE
	<div id="fieldGrpBox" style="$this->RowStyle">$nLabel
		<div id="$nRowDivID" style="clear:both;">
			<div id="fieldItem" style="$this->ItemStyle">$this->BeforeField<textarea cols="20" rows="2" name="$this->ID" id="$this->ID" style="$this->Style" $this->onBlur>$this->Value</textarea>$this->AfterField$nCaption</div>
		</div>
	</div>
CODE;
				break;
			case "rte":
				$nRTEID = "oFCKeditor".$this->ID;
				$nFormFieldCode = <<<CODE
	<div id="fieldGrpBox" style="$this->RowStyle">$nLabel
		<div id="$nRowDivID" style="clear:both;">
			<div id="fieldItem" style="$this->ItemStyle">$this->BeforeField<textarea cols="20" rows="2" name="$this->ID" id="$this->ID" style="$this->Style" $this->onBlur>$this->Value</textarea>$this->AfterField$nCaption</div>
		</div>
	</div>
<script type="text/javascript">
//window.onload = function(){
	FCKeditorAPI = null;
	__FCKeditorNS = null;
	var $nRTEID = new FCKeditor( '$this->ID' ) ;
	$nRTEID.BasePath	= 'rte/';
	$nRTEID.Config['SkinPath'] = 'skins/office2003/';
	$nRTEID.Height	= 250;
	$nRTEID.ToolbarSet = "Normal";
	$nRTEID.ReplaceTextarea();
//}
$nCloseScript
CODE;
				break;
			case "static":
				$nFormFieldCode = <<<CODE
	<div id="fieldGrpBox" style="$this->RowStyle">$nLabel
		<div id="$nRowDivID" style="clear:both;">
			<div id="fieldItem" style="$this->Style" $this->onBlur>$this->Value $nCaption</div>
		</div>
	</div>
CODE;
				break;
			case "password":
				$nFormFieldCode = <<<CODE
	<div id="fieldGrpBox" style="$this->RowStyle">$nLabel
		<div id="$nRowDivID" style="clear:both;">
			<div id="fieldItem" style="$this->ItemStyle">$this->BeforeField<input type="password" name="$this->ID" id="$this->ID" value="$this->Value" style="$this->Style" $this->onBlur>$this->AfterField$nCaption</div>
		</div>
	</div>
CODE;
				break;
			case "radio":
				// if field is required and no default selection is set, add a blank item to trigger validation
				if($nRequired && !count($this->SelectedARRAY)){ $nOptionCode.= "<input type=\"radio\" name=\"".$this->ID."\" id=\"".$this->ID."$Item\" value=\"\" checked style=\"border:none;width:auto;display:none;\" $this->onBlur>"; }
				foreach($this->DataARRAY AS $Key => $Item){
					// if form has not been posted, use default selections, otherwise use posted
					if(!$_POST["nProcess"]){
						if($this->SelectedARRAY[$Key]){ $nSel="checked"; } else { $nSel=""; }
					} else {
						if($_POST[$this->ID]==$Key){ $nSel="checked"; } else { $nSel=""; }
					}
					$nOptionCode.= "$this->BeforeField<label for=\"".$this->ID."$Key\" class=\"hand\"><input type=\"radio\" name=\"".$this->ID."\" id=\"".$this->ID."$Key\" value=\"$Key\" $nSel style=\"border:none;width:auto;$this->Style\">$Item</label>$this->AfterField";
				}
				$nFormFieldCode = <<<CODE
	<div id="fieldGrpBox" style="$this->RowStyle">$nLabel
		<div id="$nRowDivID" style="clear:both;">
			<div id="fieldItem" style="$this->ItemStyle">$nCaption $nOptionCode</div>
		</div>
	</div>
CODE;
				break;
			case "select":
				$this->onBlur = str_replace("onBlur","onChange",$this->onBlur);
				foreach($this->DataARRAY AS $Key => $Item){
					// if form has not been posted, use default selections, otherwise use posted
					if(!$_POST["nProcess"]){
						if($this->SelectedARRAY[$Key]){ $nSel="SELECTED"; } else { $nSel=""; }
					} else {
						if($_POST[$this->ID]==$Key){ $nSel="SELECTED"; } else { $nSel=""; }
					}
					$nOptionCode.= "<option value=\"$Key\" $nSel $this->onBlur>$Item</option>";
				}
				$nFormFieldCode = <<<CODE
	<div id="fieldGrpBox" style="$this->RowStyle">$nLabel
		<div id="$nRowDivID" style="clear:both;">
			<div id="fieldItem" style="$this->ItemStyle">$this->BeforeField<select name="$this->ID" id="$this->ID" style="width:auto;padding:0px;$this->Style" $this->onBlur>$nOptionCode</select> $nCaption</div>
		</div>
	</div>
CODE;
				break;
			case "multiSelect":
				$this->onBlur = str_replace("onBlur","onChange",$this->onBlur);
				foreach($this->DataARRAY AS $Key => $Item){
					// if form has not been posted, use default selections, otherwise use posted
					if(!$_POST["nProcess"]){
						if($this->SelectedARRAY[$Key]){ $nSel="SELECTED"; } else { $nSel=""; }
					} else {
						if($_POST[$this->ID]==$Key){ $nSel="SELECTED"; } else { $nSel=""; }
					}
					$nOptionCode.= "<option value=\"$Key\" $nSel $this->onBlur>$Item</option>";
				}
				$nFormFieldCode = <<<CODE
	<div id="fieldGrpBox" style="$this->RowStyle">$nLabel
		<div id="$nRowDivID" style="clear:both;">
			<div id="fieldItem" style="$this->ItemStyle">$this->BeforeField<select multiple name="$this->ID" id="$this->ID" style="width:auto;padding:0px;$this->Style" $this->onBlur>$nOptionCode</select> $nCaption</div>
		</div>
	</div>
CODE;
				break;
			case "checkbox":
				$this->onBlur = str_replace("onBlur","onClick",$this->onBlur);
				foreach($this->DataARRAY AS $Key => $Item){
					// if form has not been posted, use default selections, otherwise use posted
					if(!$_POST["nProcess"]){
						if($this->SelectedARRAY[$Key]){ $nSel="checked"; } else { $nSel=""; }
					} else {
						if($_POST[$Key]){ $nSel="checked"; } else { $nSel=""; }
					}
					$nOptionCode.= "$this->BeforeField<label for=\"$Key\" class=\"hand\"><input type=\"checkbox\" name=\"$Key\" id=\"$Key\" value=\"X\" $nSel style=\"border:none;width:auto;$this->Style\" $this->onBlur>$Item</label>$this->AfterField";
				}
				// if field is required, add a blank item to trigger validation
				if($nAddTrigger){ $nOptionCode.= "<input type=\"hidden\" name=\"$this->ID\" id=\"$this->ID\" value=\"\">"; }
				$nFormFieldCode = <<<CODE
	<div id="fieldGrpBox" style="$this->RowStyle">$nLabel
		<div id="$nRowDivID" style="clear:both;">
			<div id="fieldItem" style="$this->ItemStyle">$nCaption $nOptionCode</div>
		</div>
	</div>
CODE;
				break;
			case "file":
				$this->onBlur = str_replace("onBlur","onChange",$this->onBlur);
				$nFormFieldCode = <<<CODE
	<div id="fieldGrpBox" style="$this->RowStyle">$nLabel
		<div id="$nRowDivID" style="clear:both;">
			<div id="fieldItem" style="$this->ItemStyle">$this->BeforeField<input type="file" name="$this->ID" id="$this->ID" style="$this->Style" $this->onBlur>$this->AfterField$nCaption</div>
		</div>
	</div>
CODE;
		}
		return $nFormFieldCode;
	}
}

// Validators
function validate_email($email) { 
	$nIsValid = TRUE;
	if(eregi("^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})$", $email)) {
		$nIsValid = TRUE;
	} else {
		$nIsValid = FALSE;
	}
	return $nIsValid; 
}
function validate_num($nValue) { 
	$nIsValid = TRUE;
	if(!is_numeric($nValue)){ $nIsValid = FALSE; }
	return $nIsValid; 
}
function validate_phone($nValue){
	// removes all allowed characters and validates rest as numeric
	$nStripThese = array("(",")"," ",".","-","+");
	$nValue = str_replace($nStripThese,"",$nValue);
	return validate_num($nValue);
}
function validate_date($nValue){
	// date must be in this format: 00/00/0000
	$nRemoveMe = array("/");
	$nFormattedDate = str_replace($nRemoveMe,"",$nValue);
	if(strlen($nFormattedDate)<6 || strlen($nFormattedDate)>8){ return 0; }
	if(!is_numeric($nFormattedDate)){ return 0; }
	return 1;
}
function validate_cc($nValue){
    if(!validate_num($nValue)){ return 0; }
	$GoodCard = true;
//  Get rid of any non-digits
    $nValue = ereg_replace("[^0-9]", "", $nValue);
//  The Luhn formula works right to left, so reverse the nValueber.
    $nValue = strrev($nValue);
    $Total = 0;
    for ($x=0; $x<strlen($nValue); $x++) {
      $digit = substr($nValue,$x,1);
//    If it's an odd digit, double it
      if ($x/2 != floor($x/2)) {
        $digit *= 2;
//    If the result is two digits, add them
        if (strlen($digit) == 2)
          $digit = substr($digit,0,1) + substr($digit,1,1);
      }
//    Add the current digit, doubled and added if applicable, to the Total
      $Total += $digit;
    }
//  If it passed (or bypassed) the card-specific check and the Total is
//  evenly divisible by 10, it's cool!
    if ($GoodCard && $Total % 10 == 0) return true; else return false;
}
function validate_maxlength($nValue,$nLength){
	if(strlen($nValue)>$nLength){ return 0; }
	return 1;
}
function validate_minlength($nValue,$nLength){
	if(strlen($nValue)<$nLength){ return 0; }
	return 1;
}
?>